==> jboss-3.2.8.SP1-src.tar.bz2: jboss-3.2.8.SP1-src/testsuite/src/main/org/jboss/test/jmx/test/ProxyUnitTestCase.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.test.jmx.test;

import javax.management.MBeanServerConnection;
import javax.management.ObjectName;

import junit.framework.Test;

import org.jboss.system.ServiceMBean;
import org.jboss.test.JBossTestCase;

/**
 * Tests of mbean proxy attributes.
 *
 * @author Scott.Stark@jboss.org
 * @version $Revision: 1.1.2.3 $
 */
public class ProxyUnitTestCase
   extends JBossTestCase
{
   public ProxyUnitTestCase(String name)
   {
      super(name);
   }

   public static Test suite()
      throws Exception
   {
      return getDeploySetup(ProxyUnitTestCase.class, "jmxproxy.sar");
   }

   public void testStarted()
      throws Exception
   {
      // All the tests are done during start service
      MBeanServerConnection server = super.getServer();
      ObjectName serviceName = new ObjectName("jboss.test:name=ProxyTests");
      assertTrue("Proxy tests should be started", server.getAttribute(serviceName, "State").equals(new Integer(ServiceMBean.STARTED)));
      serviceName = new ObjectName("jboss.test:name=ProxyTestsNested");
      assertTrue("Proxy tests nested should be started", server.getAttribute(serviceName, "State").equals(new Integer(ServiceMBean.STARTED)));
      serviceName = new ObjectName("jboss.test:name=ProxyTestsAttribute");
      assertTrue("Proxy tests attribute should be started", server.getAttribute(serviceName, "State").equals(new Integer(ServiceMBean.STARTED)));
   }
}

==> jboss-4.0.3SP1-src.tar.bz2: jboss-4.0.3SP1-src/testsuite/src/main/org/jboss/test/jmx/test/ProxyUnitTestCase.java <==
/*
 * JBoss, the OpenSource J2EE webOS
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 *
 */
package org.jboss.test.jmx.test;

import javax.management.MBeanServerConnection;
import javax.management.ObjectName;

import junit.framework.Test;

import org.jboss.system.ServiceMBean;
import org.jboss.test.JBossTestCase;

/**
 * Tests of mbean proxy attributes.
 *
 * @author Scott.Stark@jboss.org
 * @version $Revision: 1.2.6.1 $
 */
public class ProxyUnitTestCase
   extends JBossTestCase
{
   public ProxyUnitTestCase(String name)
   {
      super(name);
   }

   public static Test suite()
      throws Exception
   {
      return getDeploySetup(ProxyUnitTestCase.class, "jmxproxy.sar");
   }

   public void testStarted()
      throws Exception
   {
      // All the tests are done during start service
      MBeanServerConnection server = getServer();
      ObjectName serviceName = new ObjectName("jboss.test:name=ProxyTests");
      assertTrue("Proxy tests should be started", server.getAttribute(serviceName, "State").equals(new Integer(ServiceMBean.STARTED)));
      serviceName = new ObjectName("jboss.test:name=ProxyTestsNested");
      assertTrue("Proxy tests nested should be started", server.getAttribute(serviceName, "State").equals(new Integer(ServiceMBean.STARTED)));
      serviceName = new ObjectName("jboss.test:name=ProxyTestsAttribute");
      assertTrue("Proxy tests attribute should be started", server.getAttribute(serviceName, "State").equals(new Integer(ServiceMBean.STARTED)));
   }
}
